API Reference
=============

.. automodule:: osfclient
    :members:
    :undoc-members:


osfclient.cli
-------------

.. automodule:: osfclient.cli
    :members:
    :undoc-members:
    :show-inheritance:


osfclient.utils
---------------

.. automodule:: osfclient.utils
    :members:
    :undoc-members:
    :show-inheritance:


osfclient.models
----------------

Classes to model entities in the OSF API.

.. autoclass:: osfclient.models.File
    :members:
    :undoc-members:

.. autoclass:: osfclient.models.Project
    :members:
    :undoc-members:

.. autoclass:: osfclient.models.Storage
    :members:
    :undoc-members:


Helpers and inner workings
^^^^^^^^^^^^^^^^^^^^^^^^^^

These classes do not directly model entities in the OSF API. They are used
to help with technical things in building the API.

.. autoclass:: osfclient.models.core.OSFCore
    :members:
    :undoc-members:

.. autoclass:: osfclient.models.OSFSession
    :members:
    :undoc-members:
